@@ -116,7 +116,7 @@ static void add_startupnotify_or_execute_options_to_context_menu (      GtkWidge
                                                                   const gchar       **options_array)
 {
     const gchar *menu_item_txts_exe_opts[] = { N_("Add Prompt"), N_("Add Command"), N_("Add Startupnotify") };
-    const gchar *menu_item_txts_snotify_opts[] = { N_("Add Enabled"), N_("Add Name"), N_("Add WM_CLASS") }; // Without Icon, because of context used below.s
+    const gchar *menu_item_txts_snotify_opts[] = { N_("Add Enabled"), N_("Add Name"), N_("Add WM_CLASS") }; // Without Icon, because of context used below.
     g_autofree gboolean *opts_exist = g_malloc0 (sizeof (gboolean) * number_of_opts); // Initialize all elements to FALSE.
     GtkWidget *menu_item;
     gboolean add_new_callback;
