@@ -1319,7 +1319,7 @@ gboolean get_menu_elements_from_file (gchar *new_filename)
                 escape all special characters so that the markup is used properly.
             */
             err_msg_with_escaped_markup_part_line = g_markup_escape_text (g_strstrip (menu_building.line), -1);
-            g_string_append_printf (full_errmsg, "<b>Line %i:</b>\n<tt>%s</tt>\n\n", 
+            g_string_append_printf (full_errmsg, _("<b>Line %i:</b>\n<tt>%s</tt>\n\n"), 
                                     menu_building.line_number, err_msg_with_escaped_markup_part_line);
 
             /*
